# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class BastionListEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_id': 'str',
        'allowed_access_ids': 'list[str]',
        'allowed_urls': 'list[str]',
        'allowed_urls_per_instance': 'dict(str, list[str])',
        'cluster_name': 'str',
        'display_name': 'str',
        'last_report': 'datetime'
    }

    attribute_map = {
        'access_id': 'access_id',
        'allowed_access_ids': 'allowed_access_ids',
        'allowed_urls': 'allowed_urls',
        'allowed_urls_per_instance': 'allowed_urls_per_instance',
        'cluster_name': 'cluster_name',
        'display_name': 'display_name',
        'last_report': 'last_report'
    }

    def __init__(self, access_id=None, allowed_access_ids=None, allowed_urls=None, allowed_urls_per_instance=None, cluster_name=None, display_name=None, last_report=None, local_vars_configuration=None):  # noqa: E501
        """BastionListEntry - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_id = None
        self._allowed_access_ids = None
        self._allowed_urls = None
        self._allowed_urls_per_instance = None
        self._cluster_name = None
        self._display_name = None
        self._last_report = None
        self.discriminator = None

        if access_id is not None:
            self.access_id = access_id
        if allowed_access_ids is not None:
            self.allowed_access_ids = allowed_access_ids
        if allowed_urls is not None:
            self.allowed_urls = allowed_urls
        if allowed_urls_per_instance is not None:
            self.allowed_urls_per_instance = allowed_urls_per_instance
        if cluster_name is not None:
            self.cluster_name = cluster_name
        if display_name is not None:
            self.display_name = display_name
        if last_report is not None:
            self.last_report = last_report

    @property
    def access_id(self):
        """Gets the access_id of this BastionListEntry.  # noqa: E501


        :return: The access_id of this BastionListEntry.  # noqa: E501
        :rtype: str
        """
        return self._access_id

    @access_id.setter
    def access_id(self, access_id):
        """Sets the access_id of this BastionListEntry.


        :param access_id: The access_id of this BastionListEntry.  # noqa: E501
        :type: str
        """

        self._access_id = access_id

    @property
    def allowed_access_ids(self):
        """Gets the allowed_access_ids of this BastionListEntry.  # noqa: E501


        :return: The allowed_access_ids of this BastionListEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_access_ids

    @allowed_access_ids.setter
    def allowed_access_ids(self, allowed_access_ids):
        """Sets the allowed_access_ids of this BastionListEntry.


        :param allowed_access_ids: The allowed_access_ids of this BastionListEntry.  # noqa: E501
        :type: list[str]
        """

        self._allowed_access_ids = allowed_access_ids

    @property
    def allowed_urls(self):
        """Gets the allowed_urls of this BastionListEntry.  # noqa: E501


        :return: The allowed_urls of this BastionListEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_urls

    @allowed_urls.setter
    def allowed_urls(self, allowed_urls):
        """Sets the allowed_urls of this BastionListEntry.


        :param allowed_urls: The allowed_urls of this BastionListEntry.  # noqa: E501
        :type: list[str]
        """

        self._allowed_urls = allowed_urls

    @property
    def allowed_urls_per_instance(self):
        """Gets the allowed_urls_per_instance of this BastionListEntry.  # noqa: E501


        :return: The allowed_urls_per_instance of this BastionListEntry.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._allowed_urls_per_instance

    @allowed_urls_per_instance.setter
    def allowed_urls_per_instance(self, allowed_urls_per_instance):
        """Sets the allowed_urls_per_instance of this BastionListEntry.


        :param allowed_urls_per_instance: The allowed_urls_per_instance of this BastionListEntry.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._allowed_urls_per_instance = allowed_urls_per_instance

    @property
    def cluster_name(self):
        """Gets the cluster_name of this BastionListEntry.  # noqa: E501


        :return: The cluster_name of this BastionListEntry.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this BastionListEntry.


        :param cluster_name: The cluster_name of this BastionListEntry.  # noqa: E501
        :type: str
        """

        self._cluster_name = cluster_name

    @property
    def display_name(self):
        """Gets the display_name of this BastionListEntry.  # noqa: E501


        :return: The display_name of this BastionListEntry.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BastionListEntry.


        :param display_name: The display_name of this BastionListEntry.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def last_report(self):
        """Gets the last_report of this BastionListEntry.  # noqa: E501


        :return: The last_report of this BastionListEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._last_report

    @last_report.setter
    def last_report(self, last_report):
        """Sets the last_report of this BastionListEntry.


        :param last_report: The last_report of this BastionListEntry.  # noqa: E501
        :type: datetime
        """

        self._last_report = last_report

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BastionListEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BastionListEntry):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ItemVersion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_date': 'datetime',
        'creation_date': 'datetime',
        'customer_fragment_id': 'str',
        'deletion_date': 'datetime',
        'item_version_state': 'str',
        'modification_date': 'datetime',
        'protection_key_name': 'str',
        'version': 'int',
        'with_customer_fragment': 'bool'
    }

    attribute_map = {
        'access_date': 'access_date',
        'creation_date': 'creation_date',
        'customer_fragment_id': 'customer_fragment_id',
        'deletion_date': 'deletion_date',
        'item_version_state': 'item_version_state',
        'modification_date': 'modification_date',
        'protection_key_name': 'protection_key_name',
        'version': 'version',
        'with_customer_fragment': 'with_customer_fragment'
    }

    def __init__(self, access_date=None, creation_date=None, customer_fragment_id=None, deletion_date=None, item_version_state=None, modification_date=None, protection_key_name=None, version=None, with_customer_fragment=None, local_vars_configuration=None):  # noqa: E501
        """ItemVersion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_date = None
        self._creation_date = None
        self._customer_fragment_id = None
        self._deletion_date = None
        self._item_version_state = None
        self._modification_date = None
        self._protection_key_name = None
        self._version = None
        self._with_customer_fragment = None
        self.discriminator = None

        if access_date is not None:
            self.access_date = access_date
        if creation_date is not None:
            self.creation_date = creation_date
        if customer_fragment_id is not None:
            self.customer_fragment_id = customer_fragment_id
        if deletion_date is not None:
            self.deletion_date = deletion_date
        if item_version_state is not None:
            self.item_version_state = item_version_state
        if modification_date is not None:
            self.modification_date = modification_date
        if protection_key_name is not None:
            self.protection_key_name = protection_key_name
        if version is not None:
            self.version = version
        if with_customer_fragment is not None:
            self.with_customer_fragment = with_customer_fragment

    @property
    def access_date(self):
        """Gets the access_date of this ItemVersion.  # noqa: E501


        :return: The access_date of this ItemVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._access_date

    @access_date.setter
    def access_date(self, access_date):
        """Sets the access_date of this ItemVersion.


        :param access_date: The access_date of this ItemVersion.  # noqa: E501
        :type: datetime
        """

        self._access_date = access_date

    @property
    def creation_date(self):
        """Gets the creation_date of this ItemVersion.  # noqa: E501


        :return: The creation_date of this ItemVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this ItemVersion.


        :param creation_date: The creation_date of this ItemVersion.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def customer_fragment_id(self):
        """Gets the customer_fragment_id of this ItemVersion.  # noqa: E501


        :return: The customer_fragment_id of this ItemVersion.  # noqa: E501
        :rtype: str
        """
        return self._customer_fragment_id

    @customer_fragment_id.setter
    def customer_fragment_id(self, customer_fragment_id):
        """Sets the customer_fragment_id of this ItemVersion.


        :param customer_fragment_id: The customer_fragment_id of this ItemVersion.  # noqa: E501
        :type: str
        """

        self._customer_fragment_id = customer_fragment_id

    @property
    def deletion_date(self):
        """Gets the deletion_date of this ItemVersion.  # noqa: E501


        :return: The deletion_date of this ItemVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._deletion_date

    @deletion_date.setter
    def deletion_date(self, deletion_date):
        """Sets the deletion_date of this ItemVersion.


        :param deletion_date: The deletion_date of this ItemVersion.  # noqa: E501
        :type: datetime
        """

        self._deletion_date = deletion_date

    @property
    def item_version_state(self):
        """Gets the item_version_state of this ItemVersion.  # noqa: E501

        ItemState defines the different states an Item can be in  # noqa: E501

        :return: The item_version_state of this ItemVersion.  # noqa: E501
        :rtype: str
        """
        return self._item_version_state

    @item_version_state.setter
    def item_version_state(self, item_version_state):
        """Sets the item_version_state of this ItemVersion.

        ItemState defines the different states an Item can be in  # noqa: E501

        :param item_version_state: The item_version_state of this ItemVersion.  # noqa: E501
        :type: str
        """

        self._item_version_state = item_version_state

    @property
    def modification_date(self):
        """Gets the modification_date of this ItemVersion.  # noqa: E501


        :return: The modification_date of this ItemVersion.  # noqa: E501
        :rtype: datetime
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """Sets the modification_date of this ItemVersion.


        :param modification_date: The modification_date of this ItemVersion.  # noqa: E501
        :type: datetime
        """

        self._modification_date = modification_date

    @property
    def protection_key_name(self):
        """Gets the protection_key_name of this ItemVersion.  # noqa: E501


        :return: The protection_key_name of this ItemVersion.  # noqa: E501
        :rtype: str
        """
        return self._protection_key_name

    @protection_key_name.setter
    def protection_key_name(self, protection_key_name):
        """Sets the protection_key_name of this ItemVersion.


        :param protection_key_name: The protection_key_name of this ItemVersion.  # noqa: E501
        :type: str
        """

        self._protection_key_name = protection_key_name

    @property
    def version(self):
        """Gets the version of this ItemVersion.  # noqa: E501


        :return: The version of this ItemVersion.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ItemVersion.


        :param version: The version of this ItemVersion.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def with_customer_fragment(self):
        """Gets the with_customer_fragment of this ItemVersion.  # noqa: E501


        :return: The with_customer_fragment of this ItemVersion.  # noqa: E501
        :rtype: bool
        """
        return self._with_customer_fragment

    @with_customer_fragment.setter
    def with_customer_fragment(self, with_customer_fragment):
        """Sets the with_customer_fragment of this ItemVersion.


        :param with_customer_fragment: The with_customer_fragment of this ItemVersion.  # noqa: E501
        :type: bool
        """

        self._with_customer_fragment = with_customer_fragment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemVersion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemVersion):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UniversalIdentityDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max_depth': 'int',
        'number_of_tokens': 'int',
        'root': 'UIDTokenDetails'
    }

    attribute_map = {
        'max_depth': 'max_depth',
        'number_of_tokens': 'number_of_tokens',
        'root': 'root'
    }

    def __init__(self, max_depth=None, number_of_tokens=None, root=None, local_vars_configuration=None):  # noqa: E501
        """UniversalIdentityDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._max_depth = None
        self._number_of_tokens = None
        self._root = None
        self.discriminator = None

        if max_depth is not None:
            self.max_depth = max_depth
        if number_of_tokens is not None:
            self.number_of_tokens = number_of_tokens
        if root is not None:
            self.root = root

    @property
    def max_depth(self):
        """Gets the max_depth of this UniversalIdentityDetails.  # noqa: E501


        :return: The max_depth of this UniversalIdentityDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_depth

    @max_depth.setter
    def max_depth(self, max_depth):
        """Sets the max_depth of this UniversalIdentityDetails.


        :param max_depth: The max_depth of this UniversalIdentityDetails.  # noqa: E501
        :type: int
        """

        self._max_depth = max_depth

    @property
    def number_of_tokens(self):
        """Gets the number_of_tokens of this UniversalIdentityDetails.  # noqa: E501


        :return: The number_of_tokens of this UniversalIdentityDetails.  # noqa: E501
        :rtype: int
        """
        return self._number_of_tokens

    @number_of_tokens.setter
    def number_of_tokens(self, number_of_tokens):
        """Sets the number_of_tokens of this UniversalIdentityDetails.


        :param number_of_tokens: The number_of_tokens of this UniversalIdentityDetails.  # noqa: E501
        :type: int
        """

        self._number_of_tokens = number_of_tokens

    @property
    def root(self):
        """Gets the root of this UniversalIdentityDetails.  # noqa: E501


        :return: The root of this UniversalIdentityDetails.  # noqa: E501
        :rtype: UIDTokenDetails
        """
        return self._root

    @root.setter
    def root(self, root):
        """Sets the root of this UniversalIdentityDetails.


        :param root: The root of this UniversalIdentityDetails.  # noqa: E501
        :type: UIDTokenDetails
        """

        self._root = root

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UniversalIdentityDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UniversalIdentityDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateAuthMethodOAuth2(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_expires': 'int',
        'audience': 'str',
        'bound_client_ids': 'list[str]',
        'bound_ips': 'list[str]',
        'force_sub_claims': 'bool',
        'gw_bound_ips': 'list[str]',
        'issuer': 'str',
        'json': 'bool',
        'jwks_uri': 'str',
        'jwt_ttl': 'int',
        'name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'unique_identifier': 'str'
    }

    attribute_map = {
        'access_expires': 'access-expires',
        'audience': 'audience',
        'bound_client_ids': 'bound-client-ids',
        'bound_ips': 'bound-ips',
        'force_sub_claims': 'force-sub-claims',
        'gw_bound_ips': 'gw-bound-ips',
        'issuer': 'issuer',
        'json': 'json',
        'jwks_uri': 'jwks-uri',
        'jwt_ttl': 'jwt-ttl',
        'name': 'name',
        'token': 'token',
        'uid_token': 'uid-token',
        'unique_identifier': 'unique-identifier'
    }

    def __init__(self, access_expires=0, audience=None, bound_client_ids=None, bound_ips=None, force_sub_claims=None, gw_bound_ips=None, issuer=None, json=None, jwks_uri=None, jwt_ttl=None, name=None, token=None, uid_token=None, unique_identifier=None, local_vars_configuration=None):  # noqa: E501
        """CreateAuthMethodOAuth2 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_expires = None
        self._audience = None
        self._bound_client_ids = None
        self._bound_ips = None
        self._force_sub_claims = None
        self._gw_bound_ips = None
        self._issuer = None
        self._json = None
        self._jwks_uri = None
        self._jwt_ttl = None
        self._name = None
        self._token = None
        self._uid_token = None
        self._unique_identifier = None
        self.discriminator = None

        if access_expires is not None:
            self.access_expires = access_expires
        if audience is not None:
            self.audience = audience
        if bound_client_ids is not None:
            self.bound_client_ids = bound_client_ids
        if bound_ips is not None:
            self.bound_ips = bound_ips
        if force_sub_claims is not None:
            self.force_sub_claims = force_sub_claims
        if gw_bound_ips is not None:
            self.gw_bound_ips = gw_bound_ips
        if issuer is not None:
            self.issuer = issuer
        if json is not None:
            self.json = json
        self.jwks_uri = jwks_uri
        if jwt_ttl is not None:
            self.jwt_ttl = jwt_ttl
        self.name = name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        self.unique_identifier = unique_identifier

    @property
    def access_expires(self):
        """Gets the access_expires of this CreateAuthMethodOAuth2.  # noqa: E501

        Access expiration date in Unix timestamp (select 0 for access without expiry date)  # noqa: E501

        :return: The access_expires of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: int
        """
        return self._access_expires

    @access_expires.setter
    def access_expires(self, access_expires):
        """Sets the access_expires of this CreateAuthMethodOAuth2.

        Access expiration date in Unix timestamp (select 0 for access without expiry date)  # noqa: E501

        :param access_expires: The access_expires of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: int
        """

        self._access_expires = access_expires

    @property
    def audience(self):
        """Gets the audience of this CreateAuthMethodOAuth2.  # noqa: E501

        The audience in the JWT  # noqa: E501

        :return: The audience of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this CreateAuthMethodOAuth2.

        The audience in the JWT  # noqa: E501

        :param audience: The audience of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def bound_client_ids(self):
        """Gets the bound_client_ids of this CreateAuthMethodOAuth2.  # noqa: E501

        The clients ids that the access is restricted to  # noqa: E501

        :return: The bound_client_ids of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_client_ids

    @bound_client_ids.setter
    def bound_client_ids(self, bound_client_ids):
        """Sets the bound_client_ids of this CreateAuthMethodOAuth2.

        The clients ids that the access is restricted to  # noqa: E501

        :param bound_client_ids: The bound_client_ids of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: list[str]
        """

        self._bound_client_ids = bound_client_ids

    @property
    def bound_ips(self):
        """Gets the bound_ips of this CreateAuthMethodOAuth2.  # noqa: E501

        A CIDR whitelist with the IPs that the access is restricted to  # noqa: E501

        :return: The bound_ips of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_ips

    @bound_ips.setter
    def bound_ips(self, bound_ips):
        """Sets the bound_ips of this CreateAuthMethodOAuth2.

        A CIDR whitelist with the IPs that the access is restricted to  # noqa: E501

        :param bound_ips: The bound_ips of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: list[str]
        """

        self._bound_ips = bound_ips

    @property
    def force_sub_claims(self):
        """Gets the force_sub_claims of this CreateAuthMethodOAuth2.  # noqa: E501

        if true: enforce role-association must include sub claims  # noqa: E501

        :return: The force_sub_claims of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: bool
        """
        return self._force_sub_claims

    @force_sub_claims.setter
    def force_sub_claims(self, force_sub_claims):
        """Sets the force_sub_claims of this CreateAuthMethodOAuth2.

        if true: enforce role-association must include sub claims  # noqa: E501

        :param force_sub_claims: The force_sub_claims of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: bool
        """

        self._force_sub_claims = force_sub_claims

    @property
    def gw_bound_ips(self):
        """Gets the gw_bound_ips of this CreateAuthMethodOAuth2.  # noqa: E501

        A CIDR whitelist with the GW IPs that the access is restricted to  # noqa: E501

        :return: The gw_bound_ips of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: list[str]
        """
        return self._gw_bound_ips

    @gw_bound_ips.setter
    def gw_bound_ips(self, gw_bound_ips):
        """Sets the gw_bound_ips of this CreateAuthMethodOAuth2.

        A CIDR whitelist with the GW IPs that the access is restricted to  # noqa: E501

        :param gw_bound_ips: The gw_bound_ips of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: list[str]
        """

        self._gw_bound_ips = gw_bound_ips

    @property
    def issuer(self):
        """Gets the issuer of this CreateAuthMethodOAuth2.  # noqa: E501

        Issuer URL  # noqa: E501

        :return: The issuer of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this CreateAuthMethodOAuth2.

        Issuer URL  # noqa: E501

        :param issuer: The issuer of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def json(self):
        """Gets the json of this CreateAuthMethodOAuth2.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateAuthMethodOAuth2.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def jwks_uri(self):
        """Gets the jwks_uri of this CreateAuthMethodOAuth2.  # noqa: E501

        The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.  # noqa: E501

        :return: The jwks_uri of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._jwks_uri

    @jwks_uri.setter
    def jwks_uri(self, jwks_uri):
        """Sets the jwks_uri of this CreateAuthMethodOAuth2.

        The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.  # noqa: E501

        :param jwks_uri: The jwks_uri of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and jwks_uri is None:  # noqa: E501
            raise ValueError("Invalid value for `jwks_uri`, must not be `None`")  # noqa: E501

        self._jwks_uri = jwks_uri

    @property
    def jwt_ttl(self):
        """Gets the jwt_ttl of this CreateAuthMethodOAuth2.  # noqa: E501

        Jwt TTL  # noqa: E501

        :return: The jwt_ttl of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: int
        """
        return self._jwt_ttl

    @jwt_ttl.setter
    def jwt_ttl(self, jwt_ttl):
        """Sets the jwt_ttl of this CreateAuthMethodOAuth2.

        Jwt TTL  # noqa: E501

        :param jwt_ttl: The jwt_ttl of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: int
        """

        self._jwt_ttl = jwt_ttl

    @property
    def name(self):
        """Gets the name of this CreateAuthMethodOAuth2.  # noqa: E501

        Auth Method name  # noqa: E501

        :return: The name of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateAuthMethodOAuth2.

        Auth Method name  # noqa: E501

        :param name: The name of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def token(self):
        """Gets the token of this CreateAuthMethodOAuth2.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateAuthMethodOAuth2.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateAuthMethodOAuth2.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateAuthMethodOAuth2.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def unique_identifier(self):
        """Gets the unique_identifier of this CreateAuthMethodOAuth2.  # noqa: E501

        A unique identifier (ID) value should be configured for OAuth2, LDAP and SAML authentication method types and is usually a value such as the email, username, or upn for example. Whenever a user logs in with a token, these authentication types issue a \"sub claim\" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.  # noqa: E501

        :return: The unique_identifier of this CreateAuthMethodOAuth2.  # noqa: E501
        :rtype: str
        """
        return self._unique_identifier

    @unique_identifier.setter
    def unique_identifier(self, unique_identifier):
        """Sets the unique_identifier of this CreateAuthMethodOAuth2.

        A unique identifier (ID) value should be configured for OAuth2, LDAP and SAML authentication method types and is usually a value such as the email, username, or upn for example. Whenever a user logs in with a token, these authentication types issue a \"sub claim\" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.  # noqa: E501

        :param unique_identifier: The unique_identifier of this CreateAuthMethodOAuth2.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and unique_identifier is None:  # noqa: E501
            raise ValueError("Invalid value for `unique_identifier`, must not be `None`")  # noqa: E501

        self._unique_identifier = unique_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAuthMethodOAuth2):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateAuthMethodOAuth2):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ClassicKeyTargetInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'external_kms_id': 'ExternalKMSKeyId',
        'key_purpose': 'list[str]',
        'key_status': 'ClassicKeyStatusInfo',
        'target_assoc_id': 'str',
        'target_type': 'str'
    }

    attribute_map = {
        'external_kms_id': 'external_kms_id',
        'key_purpose': 'key_purpose',
        'key_status': 'key_status',
        'target_assoc_id': 'target_assoc_id',
        'target_type': 'target_type'
    }

    def __init__(self, external_kms_id=None, key_purpose=None, key_status=None, target_assoc_id=None, target_type=None, local_vars_configuration=None):  # noqa: E501
        """ClassicKeyTargetInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._external_kms_id = None
        self._key_purpose = None
        self._key_status = None
        self._target_assoc_id = None
        self._target_type = None
        self.discriminator = None

        if external_kms_id is not None:
            self.external_kms_id = external_kms_id
        if key_purpose is not None:
            self.key_purpose = key_purpose
        if key_status is not None:
            self.key_status = key_status
        if target_assoc_id is not None:
            self.target_assoc_id = target_assoc_id
        if target_type is not None:
            self.target_type = target_type

    @property
    def external_kms_id(self):
        """Gets the external_kms_id of this ClassicKeyTargetInfo.  # noqa: E501


        :return: The external_kms_id of this ClassicKeyTargetInfo.  # noqa: E501
        :rtype: ExternalKMSKeyId
        """
        return self._external_kms_id

    @external_kms_id.setter
    def external_kms_id(self, external_kms_id):
        """Sets the external_kms_id of this ClassicKeyTargetInfo.


        :param external_kms_id: The external_kms_id of this ClassicKeyTargetInfo.  # noqa: E501
        :type: ExternalKMSKeyId
        """

        self._external_kms_id = external_kms_id

    @property
    def key_purpose(self):
        """Gets the key_purpose of this ClassicKeyTargetInfo.  # noqa: E501


        :return: The key_purpose of this ClassicKeyTargetInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._key_purpose

    @key_purpose.setter
    def key_purpose(self, key_purpose):
        """Sets the key_purpose of this ClassicKeyTargetInfo.


        :param key_purpose: The key_purpose of this ClassicKeyTargetInfo.  # noqa: E501
        :type: list[str]
        """

        self._key_purpose = key_purpose

    @property
    def key_status(self):
        """Gets the key_status of this ClassicKeyTargetInfo.  # noqa: E501


        :return: The key_status of this ClassicKeyTargetInfo.  # noqa: E501
        :rtype: ClassicKeyStatusInfo
        """
        return self._key_status

    @key_status.setter
    def key_status(self, key_status):
        """Sets the key_status of this ClassicKeyTargetInfo.


        :param key_status: The key_status of this ClassicKeyTargetInfo.  # noqa: E501
        :type: ClassicKeyStatusInfo
        """

        self._key_status = key_status

    @property
    def target_assoc_id(self):
        """Gets the target_assoc_id of this ClassicKeyTargetInfo.  # noqa: E501


        :return: The target_assoc_id of this ClassicKeyTargetInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_assoc_id

    @target_assoc_id.setter
    def target_assoc_id(self, target_assoc_id):
        """Sets the target_assoc_id of this ClassicKeyTargetInfo.


        :param target_assoc_id: The target_assoc_id of this ClassicKeyTargetInfo.  # noqa: E501
        :type: str
        """

        self._target_assoc_id = target_assoc_id

    @property
    def target_type(self):
        """Gets the target_type of this ClassicKeyTargetInfo.  # noqa: E501


        :return: The target_type of this ClassicKeyTargetInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_type

    @target_type.setter
    def target_type(self, target_type):
        """Sets the target_type of this ClassicKeyTargetInfo.


        :param target_type: The target_type of this ClassicKeyTargetInfo.  # noqa: E501
        :type: str
        """

        self._target_type = target_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassicKeyTargetInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClassicKeyTargetInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Target(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_date': 'datetime',
        'access_request_status': 'str',
        'attributes': 'dict(str, object)',
        'client_permissions': 'list[str]',
        'comment': 'str',
        'creation_date': 'datetime',
        'credentials_less': 'bool',
        'is_access_request_enabled': 'bool',
        'last_version': 'int',
        'modification_date': 'datetime',
        'protection_key_name': 'str',
        'target_id': 'int',
        'target_items_assoc': 'list[TargetItemAssociation]',
        'target_name': 'str',
        'target_type': 'str',
        'target_versions': 'list[ItemVersion]',
        'with_customer_fragment': 'bool'
    }

    attribute_map = {
        'access_date': 'access_date',
        'access_request_status': 'access_request_status',
        'attributes': 'attributes',
        'client_permissions': 'client_permissions',
        'comment': 'comment',
        'creation_date': 'creation_date',
        'credentials_less': 'credentials_less',
        'is_access_request_enabled': 'is_access_request_enabled',
        'last_version': 'last_version',
        'modification_date': 'modification_date',
        'protection_key_name': 'protection_key_name',
        'target_id': 'target_id',
        'target_items_assoc': 'target_items_assoc',
        'target_name': 'target_name',
        'target_type': 'target_type',
        'target_versions': 'target_versions',
        'with_customer_fragment': 'with_customer_fragment'
    }

    def __init__(self, access_date=None, access_request_status=None, attributes=None, client_permissions=None, comment=None, creation_date=None, credentials_less=None, is_access_request_enabled=None, last_version=None, modification_date=None, protection_key_name=None, target_id=None, target_items_assoc=None, target_name=None, target_type=None, target_versions=None, with_customer_fragment=None, local_vars_configuration=None):  # noqa: E501
        """Target - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_date = None
        self._access_request_status = None
        self._attributes = None
        self._client_permissions = None
        self._comment = None
        self._creation_date = None
        self._credentials_less = None
        self._is_access_request_enabled = None
        self._last_version = None
        self._modification_date = None
        self._protection_key_name = None
        self._target_id = None
        self._target_items_assoc = None
        self._target_name = None
        self._target_type = None
        self._target_versions = None
        self._with_customer_fragment = None
        self.discriminator = None

        if access_date is not None:
            self.access_date = access_date
        if access_request_status is not None:
            self.access_request_status = access_request_status
        if attributes is not None:
            self.attributes = attributes
        if client_permissions is not None:
            self.client_permissions = client_permissions
        if comment is not None:
            self.comment = comment
        if creation_date is not None:
            self.creation_date = creation_date
        if credentials_less is not None:
            self.credentials_less = credentials_less
        if is_access_request_enabled is not None:
            self.is_access_request_enabled = is_access_request_enabled
        if last_version is not None:
            self.last_version = last_version
        if modification_date is not None:
            self.modification_date = modification_date
        if protection_key_name is not None:
            self.protection_key_name = protection_key_name
        if target_id is not None:
            self.target_id = target_id
        if target_items_assoc is not None:
            self.target_items_assoc = target_items_assoc
        if target_name is not None:
            self.target_name = target_name
        if target_type is not None:
            self.target_type = target_type
        if target_versions is not None:
            self.target_versions = target_versions
        if with_customer_fragment is not None:
            self.with_customer_fragment = with_customer_fragment

    @property
    def access_date(self):
        """Gets the access_date of this Target.  # noqa: E501


        :return: The access_date of this Target.  # noqa: E501
        :rtype: datetime
        """
        return self._access_date

    @access_date.setter
    def access_date(self, access_date):
        """Sets the access_date of this Target.


        :param access_date: The access_date of this Target.  # noqa: E501
        :type: datetime
        """

        self._access_date = access_date

    @property
    def access_request_status(self):
        """Gets the access_request_status of this Target.  # noqa: E501


        :return: The access_request_status of this Target.  # noqa: E501
        :rtype: str
        """
        return self._access_request_status

    @access_request_status.setter
    def access_request_status(self, access_request_status):
        """Sets the access_request_status of this Target.


        :param access_request_status: The access_request_status of this Target.  # noqa: E501
        :type: str
        """

        self._access_request_status = access_request_status

    @property
    def attributes(self):
        """Gets the attributes of this Target.  # noqa: E501

        this is not \"omitempty\" since an empty value causes no update while an empty map will clear the attributes  # noqa: E501

        :return: The attributes of this Target.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this Target.

        this is not \"omitempty\" since an empty value causes no update while an empty map will clear the attributes  # noqa: E501

        :param attributes: The attributes of this Target.  # noqa: E501
        :type: dict(str, object)
        """

        self._attributes = attributes

    @property
    def client_permissions(self):
        """Gets the client_permissions of this Target.  # noqa: E501


        :return: The client_permissions of this Target.  # noqa: E501
        :rtype: list[str]
        """
        return self._client_permissions

    @client_permissions.setter
    def client_permissions(self, client_permissions):
        """Sets the client_permissions of this Target.


        :param client_permissions: The client_permissions of this Target.  # noqa: E501
        :type: list[str]
        """

        self._client_permissions = client_permissions

    @property
    def comment(self):
        """Gets the comment of this Target.  # noqa: E501


        :return: The comment of this Target.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Target.


        :param comment: The comment of this Target.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def creation_date(self):
        """Gets the creation_date of this Target.  # noqa: E501


        :return: The creation_date of this Target.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this Target.


        :param creation_date: The creation_date of this Target.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def credentials_less(self):
        """Gets the credentials_less of this Target.  # noqa: E501


        :return: The credentials_less of this Target.  # noqa: E501
        :rtype: bool
        """
        return self._credentials_less

    @credentials_less.setter
    def credentials_less(self, credentials_less):
        """Sets the credentials_less of this Target.


        :param credentials_less: The credentials_less of this Target.  # noqa: E501
        :type: bool
        """

        self._credentials_less = credentials_less

    @property
    def is_access_request_enabled(self):
        """Gets the is_access_request_enabled of this Target.  # noqa: E501


        :return: The is_access_request_enabled of this Target.  # noqa: E501
        :rtype: bool
        """
        return self._is_access_request_enabled

    @is_access_request_enabled.setter
    def is_access_request_enabled(self, is_access_request_enabled):
        """Sets the is_access_request_enabled of this Target.


        :param is_access_request_enabled: The is_access_request_enabled of this Target.  # noqa: E501
        :type: bool
        """

        self._is_access_request_enabled = is_access_request_enabled

    @property
    def last_version(self):
        """Gets the last_version of this Target.  # noqa: E501


        :return: The last_version of this Target.  # noqa: E501
        :rtype: int
        """
        return self._last_version

    @last_version.setter
    def last_version(self, last_version):
        """Sets the last_version of this Target.


        :param last_version: The last_version of this Target.  # noqa: E501
        :type: int
        """

        self._last_version = last_version

    @property
    def modification_date(self):
        """Gets the modification_date of this Target.  # noqa: E501


        :return: The modification_date of this Target.  # noqa: E501
        :rtype: datetime
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """Sets the modification_date of this Target.


        :param modification_date: The modification_date of this Target.  # noqa: E501
        :type: datetime
        """

        self._modification_date = modification_date

    @property
    def protection_key_name(self):
        """Gets the protection_key_name of this Target.  # noqa: E501


        :return: The protection_key_name of this Target.  # noqa: E501
        :rtype: str
        """
        return self._protection_key_name

    @protection_key_name.setter
    def protection_key_name(self, protection_key_name):
        """Sets the protection_key_name of this Target.


        :param protection_key_name: The protection_key_name of this Target.  # noqa: E501
        :type: str
        """

        self._protection_key_name = protection_key_name

    @property
    def target_id(self):
        """Gets the target_id of this Target.  # noqa: E501


        :return: The target_id of this Target.  # noqa: E501
        :rtype: int
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this Target.


        :param target_id: The target_id of this Target.  # noqa: E501
        :type: int
        """

        self._target_id = target_id

    @property
    def target_items_assoc(self):
        """Gets the target_items_assoc of this Target.  # noqa: E501


        :return: The target_items_assoc of this Target.  # noqa: E501
        :rtype: list[TargetItemAssociation]
        """
        return self._target_items_assoc

    @target_items_assoc.setter
    def target_items_assoc(self, target_items_assoc):
        """Sets the target_items_assoc of this Target.


        :param target_items_assoc: The target_items_assoc of this Target.  # noqa: E501
        :type: list[TargetItemAssociation]
        """

        self._target_items_assoc = target_items_assoc

    @property
    def target_name(self):
        """Gets the target_name of this Target.  # noqa: E501


        :return: The target_name of this Target.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this Target.


        :param target_name: The target_name of this Target.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def target_type(self):
        """Gets the target_type of this Target.  # noqa: E501


        :return: The target_type of this Target.  # noqa: E501
        :rtype: str
        """
        return self._target_type

    @target_type.setter
    def target_type(self, target_type):
        """Sets the target_type of this Target.


        :param target_type: The target_type of this Target.  # noqa: E501
        :type: str
        """

        self._target_type = target_type

    @property
    def target_versions(self):
        """Gets the target_versions of this Target.  # noqa: E501


        :return: The target_versions of this Target.  # noqa: E501
        :rtype: list[ItemVersion]
        """
        return self._target_versions

    @target_versions.setter
    def target_versions(self, target_versions):
        """Sets the target_versions of this Target.


        :param target_versions: The target_versions of this Target.  # noqa: E501
        :type: list[ItemVersion]
        """

        self._target_versions = target_versions

    @property
    def with_customer_fragment(self):
        """Gets the with_customer_fragment of this Target.  # noqa: E501


        :return: The with_customer_fragment of this Target.  # noqa: E501
        :rtype: bool
        """
        return self._with_customer_fragment

    @with_customer_fragment.setter
    def with_customer_fragment(self, with_customer_fragment):
        """Sets the with_customer_fragment of this Target.


        :param with_customer_fragment: The with_customer_fragment of this Target.  # noqa: E501
        :type: bool
        """

        self._with_customer_fragment = with_customer_fragment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Target):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Target):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.kmip_client_list_response import KMIPClientListResponse  # noqa: E501
from akeyless.rest import ApiException

class TestKMIPClientListResponse(unittest.TestCase):
    """KMIPClientListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test KMIPClientListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.kmip_client_list_response.KMIPClientListResponse()  # noqa: E501
        if include_optional :
            return KMIPClientListResponse(
                clients = [
                    akeyless.models.kmip_client.KMIPClient(
                        certificate_issue_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '0', 
                        name = '0', 
                        rules = [
                            akeyless.models.path_rule_is_a_single_rule_used_in_akeyless_rbac/.PathRule is a single rule used in AKEYLESS RBAC.(
                                capabilities = [
                                    '0'
                                    ], 
                                path = '0', 
                                type = '0', )
                            ], )
                    ]
            )
        else :
            return KMIPClientListResponse(
        )

    def testKMIPClientListResponse(self):
        """Test KMIPClientListResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerCustom(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'admin_rotation_interval_days': 'int',
        'create_sync_url': 'str',
        'delete_protection': 'str',
        'enable_admin_rotation': 'bool',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'payload': 'str',
        'producer_encryption_key_name': 'str',
        'revoke_sync_url': 'str',
        'rotate_sync_url': 'str',
        'tags': 'list[str]',
        'timeout_sec': 'int',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'admin_rotation_interval_days': 'admin_rotation_interval_days',
        'create_sync_url': 'create-sync-url',
        'delete_protection': 'delete_protection',
        'enable_admin_rotation': 'enable_admin_rotation',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'payload': 'payload',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'revoke_sync_url': 'revoke-sync-url',
        'rotate_sync_url': 'rotate-sync-url',
        'tags': 'tags',
        'timeout_sec': 'timeout-sec',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, admin_rotation_interval_days=None, create_sync_url=None, delete_protection=None, enable_admin_rotation=False, json=None, name=None, new_name=None, payload=None, producer_encryption_key_name=None, revoke_sync_url=None, rotate_sync_url=None, tags=None, timeout_sec=60, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerCustom - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._admin_rotation_interval_days = None
        self._create_sync_url = None
        self._delete_protection = None
        self._enable_admin_rotation = None
        self._json = None
        self._name = None
        self._new_name = None
        self._payload = None
        self._producer_encryption_key_name = None
        self._revoke_sync_url = None
        self._rotate_sync_url = None
        self._tags = None
        self._timeout_sec = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if admin_rotation_interval_days is not None:
            self.admin_rotation_interval_days = admin_rotation_interval_days
        self.create_sync_url = create_sync_url
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if enable_admin_rotation is not None:
            self.enable_admin_rotation = enable_admin_rotation
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if payload is not None:
            self.payload = payload
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        self.revoke_sync_url = revoke_sync_url
        if rotate_sync_url is not None:
            self.rotate_sync_url = rotate_sync_url
        if tags is not None:
            self.tags = tags
        if timeout_sec is not None:
            self.timeout_sec = timeout_sec
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def admin_rotation_interval_days(self):
        """Gets the admin_rotation_interval_days of this GatewayUpdateProducerCustom.  # noqa: E501

        Define rotation interval in days  # noqa: E501

        :return: The admin_rotation_interval_days of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: int
        """
        return self._admin_rotation_interval_days

    @admin_rotation_interval_days.setter
    def admin_rotation_interval_days(self, admin_rotation_interval_days):
        """Sets the admin_rotation_interval_days of this GatewayUpdateProducerCustom.

        Define rotation interval in days  # noqa: E501

        :param admin_rotation_interval_days: The admin_rotation_interval_days of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: int
        """

        self._admin_rotation_interval_days = admin_rotation_interval_days

    @property
    def create_sync_url(self):
        """Gets the create_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501

        URL of an endpoint that implements /sync/create method, for example https://webhook.example.com/sync/create  # noqa: E501

        :return: The create_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._create_sync_url

    @create_sync_url.setter
    def create_sync_url(self, create_sync_url):
        """Sets the create_sync_url of this GatewayUpdateProducerCustom.

        URL of an endpoint that implements /sync/create method, for example https://webhook.example.com/sync/create  # noqa: E501

        :param create_sync_url: The create_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and create_sync_url is None:  # noqa: E501
            raise ValueError("Invalid value for `create_sync_url`, must not be `None`")  # noqa: E501

        self._create_sync_url = create_sync_url

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerCustom.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerCustom.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def enable_admin_rotation(self):
        """Gets the enable_admin_rotation of this GatewayUpdateProducerCustom.  # noqa: E501

        Should admin credentials be rotated  # noqa: E501

        :return: The enable_admin_rotation of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: bool
        """
        return self._enable_admin_rotation

    @enable_admin_rotation.setter
    def enable_admin_rotation(self, enable_admin_rotation):
        """Sets the enable_admin_rotation of this GatewayUpdateProducerCustom.

        Should admin credentials be rotated  # noqa: E501

        :param enable_admin_rotation: The enable_admin_rotation of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: bool
        """

        self._enable_admin_rotation = enable_admin_rotation

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerCustom.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerCustom.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerCustom.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerCustom.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerCustom.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerCustom.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def payload(self):
        """Gets the payload of this GatewayUpdateProducerCustom.  # noqa: E501

        Secret payload to be sent with each create/revoke webhook request  # noqa: E501

        :return: The payload of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """Sets the payload of this GatewayUpdateProducerCustom.

        Secret payload to be sent with each create/revoke webhook request  # noqa: E501

        :param payload: The payload of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._payload = payload

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerCustom.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerCustom.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def revoke_sync_url(self):
        """Gets the revoke_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501

        URL of an endpoint that implements /sync/revoke method, for example https://webhook.example.com/sync/revoke  # noqa: E501

        :return: The revoke_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._revoke_sync_url

    @revoke_sync_url.setter
    def revoke_sync_url(self, revoke_sync_url):
        """Sets the revoke_sync_url of this GatewayUpdateProducerCustom.

        URL of an endpoint that implements /sync/revoke method, for example https://webhook.example.com/sync/revoke  # noqa: E501

        :param revoke_sync_url: The revoke_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and revoke_sync_url is None:  # noqa: E501
            raise ValueError("Invalid value for `revoke_sync_url`, must not be `None`")  # noqa: E501

        self._revoke_sync_url = revoke_sync_url

    @property
    def rotate_sync_url(self):
        """Gets the rotate_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501

        URL of an endpoint that implements /sync/rotate method, for example https://webhook.example.com/sync/rotate  # noqa: E501

        :return: The rotate_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._rotate_sync_url

    @rotate_sync_url.setter
    def rotate_sync_url(self, rotate_sync_url):
        """Sets the rotate_sync_url of this GatewayUpdateProducerCustom.

        URL of an endpoint that implements /sync/rotate method, for example https://webhook.example.com/sync/rotate  # noqa: E501

        :param rotate_sync_url: The rotate_sync_url of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._rotate_sync_url = rotate_sync_url

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerCustom.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerCustom.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def timeout_sec(self):
        """Gets the timeout_sec of this GatewayUpdateProducerCustom.  # noqa: E501

        Maximum allowed time in seconds for the webhook to return the results  # noqa: E501

        :return: The timeout_sec of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: int
        """
        return self._timeout_sec

    @timeout_sec.setter
    def timeout_sec(self, timeout_sec):
        """Sets the timeout_sec of this GatewayUpdateProducerCustom.

        Maximum allowed time in seconds for the webhook to return the results  # noqa: E501

        :param timeout_sec: The timeout_sec of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: int
        """

        self._timeout_sec = timeout_sec

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerCustom.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerCustom.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerCustom.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerCustom.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerCustom.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerCustom.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerCustom.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerCustom.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerCustom):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerCustom):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ManagedKeyDetailsInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_provided_by_user': 'bool',
        'is_unexportable': 'bool',
        'key_state': 'str',
        'key_type': 'str',
        'managed_key_id': 'str',
        'target_alias_helper': 'str',
        'targets': 'list[ManagedKeyTargetInfo]'
    }

    attribute_map = {
        'is_provided_by_user': 'is_provided_by_user',
        'is_unexportable': 'is_unexportable',
        'key_state': 'key_state',
        'key_type': 'key_type',
        'managed_key_id': 'managed_key_id',
        'target_alias_helper': 'target_alias_helper',
        'targets': 'targets'
    }

    def __init__(self, is_provided_by_user=None, is_unexportable=None, key_state=None, key_type=None, managed_key_id=None, target_alias_helper=None, targets=None, local_vars_configuration=None):  # noqa: E501
        """ManagedKeyDetailsInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._is_provided_by_user = None
        self._is_unexportable = None
        self._key_state = None
        self._key_type = None
        self._managed_key_id = None
        self._target_alias_helper = None
        self._targets = None
        self.discriminator = None

        if is_provided_by_user is not None:
            self.is_provided_by_user = is_provided_by_user
        if is_unexportable is not None:
            self.is_unexportable = is_unexportable
        if key_state is not None:
            self.key_state = key_state
        if key_type is not None:
            self.key_type = key_type
        if managed_key_id is not None:
            self.managed_key_id = managed_key_id
        if target_alias_helper is not None:
            self.target_alias_helper = target_alias_helper
        if targets is not None:
            self.targets = targets

    @property
    def is_provided_by_user(self):
        """Gets the is_provided_by_user of this ManagedKeyDetailsInfo.  # noqa: E501


        :return: The is_provided_by_user of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_provided_by_user

    @is_provided_by_user.setter
    def is_provided_by_user(self, is_provided_by_user):
        """Sets the is_provided_by_user of this ManagedKeyDetailsInfo.


        :param is_provided_by_user: The is_provided_by_user of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: bool
        """

        self._is_provided_by_user = is_provided_by_user

    @property
    def is_unexportable(self):
        """Gets the is_unexportable of this ManagedKeyDetailsInfo.  # noqa: E501


        :return: The is_unexportable of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_unexportable

    @is_unexportable.setter
    def is_unexportable(self, is_unexportable):
        """Sets the is_unexportable of this ManagedKeyDetailsInfo.


        :param is_unexportable: The is_unexportable of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: bool
        """

        self._is_unexportable = is_unexportable

    @property
    def key_state(self):
        """Gets the key_state of this ManagedKeyDetailsInfo.  # noqa: E501

        ItemState defines the different states an Item can be in  # noqa: E501

        :return: The key_state of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._key_state

    @key_state.setter
    def key_state(self, key_state):
        """Sets the key_state of this ManagedKeyDetailsInfo.

        ItemState defines the different states an Item can be in  # noqa: E501

        :param key_state: The key_state of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: str
        """

        self._key_state = key_state

    @property
    def key_type(self):
        """Gets the key_type of this ManagedKeyDetailsInfo.  # noqa: E501


        :return: The key_type of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._key_type

    @key_type.setter
    def key_type(self, key_type):
        """Sets the key_type of this ManagedKeyDetailsInfo.


        :param key_type: The key_type of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: str
        """

        self._key_type = key_type

    @property
    def managed_key_id(self):
        """Gets the managed_key_id of this ManagedKeyDetailsInfo.  # noqa: E501


        :return: The managed_key_id of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._managed_key_id

    @managed_key_id.setter
    def managed_key_id(self, managed_key_id):
        """Sets the managed_key_id of this ManagedKeyDetailsInfo.


        :param managed_key_id: The managed_key_id of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: str
        """

        self._managed_key_id = managed_key_id

    @property
    def target_alias_helper(self):
        """Gets the target_alias_helper of this ManagedKeyDetailsInfo.  # noqa: E501


        :return: The target_alias_helper of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_alias_helper

    @target_alias_helper.setter
    def target_alias_helper(self, target_alias_helper):
        """Sets the target_alias_helper of this ManagedKeyDetailsInfo.


        :param target_alias_helper: The target_alias_helper of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: str
        """

        self._target_alias_helper = target_alias_helper

    @property
    def targets(self):
        """Gets the targets of this ManagedKeyDetailsInfo.  # noqa: E501


        :return: The targets of this ManagedKeyDetailsInfo.  # noqa: E501
        :rtype: list[ManagedKeyTargetInfo]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """Sets the targets of this ManagedKeyDetailsInfo.


        :param targets: The targets of this ManagedKeyDetailsInfo.  # noqa: E501
        :type: list[ManagedKeyTargetInfo]
        """

        self._targets = targets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ManagedKeyDetailsInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ManagedKeyDetailsInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class SAMLAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_redirect_ur_is': 'list[str]',
        'bound_attributes': 'list[SAMLAttribute]',
        'idp_metadata_url': 'str',
        'idp_metadata_xml': 'str',
        'unique_identifier': 'str'
    }

    attribute_map = {
        'allowed_redirect_ur_is': 'allowed_redirect_URIs',
        'bound_attributes': 'bound_attributes',
        'idp_metadata_url': 'idp_metadata_url',
        'idp_metadata_xml': 'idp_metadata_xml',
        'unique_identifier': 'unique_identifier'
    }

    def __init__(self, allowed_redirect_ur_is=None, bound_attributes=None, idp_metadata_url=None, idp_metadata_xml=None, unique_identifier=None, local_vars_configuration=None):  # noqa: E501
        """SAMLAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_redirect_ur_is = None
        self._bound_attributes = None
        self._idp_metadata_url = None
        self._idp_metadata_xml = None
        self._unique_identifier = None
        self.discriminator = None

        if allowed_redirect_ur_is is not None:
            self.allowed_redirect_ur_is = allowed_redirect_ur_is
        if bound_attributes is not None:
            self.bound_attributes = bound_attributes
        if idp_metadata_url is not None:
            self.idp_metadata_url = idp_metadata_url
        if idp_metadata_xml is not None:
            self.idp_metadata_xml = idp_metadata_xml
        if unique_identifier is not None:
            self.unique_identifier = unique_identifier

    @property
    def allowed_redirect_ur_is(self):
        """Gets the allowed_redirect_ur_is of this SAMLAccessRules.  # noqa: E501

        Allowed redirect URIs after the authentication  # noqa: E501

        :return: The allowed_redirect_ur_is of this SAMLAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_redirect_ur_is

    @allowed_redirect_ur_is.setter
    def allowed_redirect_ur_is(self, allowed_redirect_ur_is):
        """Sets the allowed_redirect_ur_is of this SAMLAccessRules.

        Allowed redirect URIs after the authentication  # noqa: E501

        :param allowed_redirect_ur_is: The allowed_redirect_ur_is of this SAMLAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._allowed_redirect_ur_is = allowed_redirect_ur_is

    @property
    def bound_attributes(self):
        """Gets the bound_attributes of this SAMLAccessRules.  # noqa: E501

        The attributes that login is restricted to.  # noqa: E501

        :return: The bound_attributes of this SAMLAccessRules.  # noqa: E501
        :rtype: list[SAMLAttribute]
        """
        return self._bound_attributes

    @bound_attributes.setter
    def bound_attributes(self, bound_attributes):
        """Sets the bound_attributes of this SAMLAccessRules.

        The attributes that login is restricted to.  # noqa: E501

        :param bound_attributes: The bound_attributes of this SAMLAccessRules.  # noqa: E501
        :type: list[SAMLAttribute]
        """

        self._bound_attributes = bound_attributes

    @property
    def idp_metadata_url(self):
        """Gets the idp_metadata_url of this SAMLAccessRules.  # noqa: E501

        IDP metadata url  # noqa: E501

        :return: The idp_metadata_url of this SAMLAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._idp_metadata_url

    @idp_metadata_url.setter
    def idp_metadata_url(self, idp_metadata_url):
        """Sets the idp_metadata_url of this SAMLAccessRules.

        IDP metadata url  # noqa: E501

        :param idp_metadata_url: The idp_metadata_url of this SAMLAccessRules.  # noqa: E501
        :type: str
        """

        self._idp_metadata_url = idp_metadata_url

    @property
    def idp_metadata_xml(self):
        """Gets the idp_metadata_xml of this SAMLAccessRules.  # noqa: E501

        IDP metadata XML  # noqa: E501

        :return: The idp_metadata_xml of this SAMLAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._idp_metadata_xml

    @idp_metadata_xml.setter
    def idp_metadata_xml(self, idp_metadata_xml):
        """Sets the idp_metadata_xml of this SAMLAccessRules.

        IDP metadata XML  # noqa: E501

        :param idp_metadata_xml: The idp_metadata_xml of this SAMLAccessRules.  # noqa: E501
        :type: str
        """

        self._idp_metadata_xml = idp_metadata_xml

    @property
    def unique_identifier(self):
        """Gets the unique_identifier of this SAMLAccessRules.  # noqa: E501

        A unique identifier to distinguish different users  # noqa: E501

        :return: The unique_identifier of this SAMLAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._unique_identifier

    @unique_identifier.setter
    def unique_identifier(self, unique_identifier):
        """Sets the unique_identifier of this SAMLAccessRules.

        A unique identifier to distinguish different users  # noqa: E501

        :param unique_identifier: The unique_identifier of this SAMLAccessRules.  # noqa: E501
        :type: str
        """

        self._unique_identifier = unique_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SAMLAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SAMLAccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateSSHCertIssuer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'add_tag': 'list[str]',
        'allowed_users': 'str',
        'extensions': 'dict(str, str)',
        'json': 'bool',
        'metadata': 'str',
        'name': 'str',
        'new_name': 'str',
        'principals': 'str',
        'rm_tag': 'list[str]',
        'secure_access_bastion_api': 'str',
        'secure_access_bastion_ssh': 'str',
        'secure_access_enable': 'str',
        'secure_access_host': 'list[str]',
        'secure_access_ssh_creds_user': 'str',
        'secure_access_use_internal_bastion': 'bool',
        'signer_key_name': 'str',
        'token': 'str',
        'ttl': 'int',
        'uid_token': 'str'
    }

    attribute_map = {
        'add_tag': 'add-tag',
        'allowed_users': 'allowed-users',
        'extensions': 'extensions',
        'json': 'json',
        'metadata': 'metadata',
        'name': 'name',
        'new_name': 'new-name',
        'principals': 'principals',
        'rm_tag': 'rm-tag',
        'secure_access_bastion_api': 'secure-access-bastion-api',
        'secure_access_bastion_ssh': 'secure-access-bastion-ssh',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_host': 'secure-access-host',
        'secure_access_ssh_creds_user': 'secure-access-ssh-creds-user',
        'secure_access_use_internal_bastion': 'secure-access-use-internal-bastion',
        'signer_key_name': 'signer-key-name',
        'token': 'token',
        'ttl': 'ttl',
        'uid_token': 'uid-token'
    }

    def __init__(self, add_tag=None, allowed_users=None, extensions=None, json=None, metadata=None, name=None, new_name=None, principals=None, rm_tag=None, secure_access_bastion_api=None, secure_access_bastion_ssh=None, secure_access_enable=None, secure_access_host=None, secure_access_ssh_creds_user=None, secure_access_use_internal_bastion=None, signer_key_name=None, token=None, ttl=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """UpdateSSHCertIssuer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._add_tag = None
        self._allowed_users = None
        self._extensions = None
        self._json = None
        self._metadata = None
        self._name = None
        self._new_name = None
        self._principals = None
        self._rm_tag = None
        self._secure_access_bastion_api = None
        self._secure_access_bastion_ssh = None
        self._secure_access_enable = None
        self._secure_access_host = None
        self._secure_access_ssh_creds_user = None
        self._secure_access_use_internal_bastion = None
        self._signer_key_name = None
        self._token = None
        self._ttl = None
        self._uid_token = None
        self.discriminator = None

        if add_tag is not None:
            self.add_tag = add_tag
        self.allowed_users = allowed_users
        if extensions is not None:
            self.extensions = extensions
        if json is not None:
            self.json = json
        if metadata is not None:
            self.metadata = metadata
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if principals is not None:
            self.principals = principals
        if rm_tag is not None:
            self.rm_tag = rm_tag
        if secure_access_bastion_api is not None:
            self.secure_access_bastion_api = secure_access_bastion_api
        if secure_access_bastion_ssh is not None:
            self.secure_access_bastion_ssh = secure_access_bastion_ssh
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_host is not None:
            self.secure_access_host = secure_access_host
        if secure_access_ssh_creds_user is not None:
            self.secure_access_ssh_creds_user = secure_access_ssh_creds_user
        if secure_access_use_internal_bastion is not None:
            self.secure_access_use_internal_bastion = secure_access_use_internal_bastion
        self.signer_key_name = signer_key_name
        if token is not None:
            self.token = token
        self.ttl = ttl
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def add_tag(self):
        """Gets the add_tag of this UpdateSSHCertIssuer.  # noqa: E501

        List of the new tags that will be attached to this item  # noqa: E501

        :return: The add_tag of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_tag

    @add_tag.setter
    def add_tag(self, add_tag):
        """Sets the add_tag of this UpdateSSHCertIssuer.

        List of the new tags that will be attached to this item  # noqa: E501

        :param add_tag: The add_tag of this UpdateSSHCertIssuer.  # noqa: E501
        :type: list[str]
        """

        self._add_tag = add_tag

    @property
    def allowed_users(self):
        """Gets the allowed_users of this UpdateSSHCertIssuer.  # noqa: E501

        Users allowed to fetch the certificate, e.g root,ubuntu  # noqa: E501

        :return: The allowed_users of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._allowed_users

    @allowed_users.setter
    def allowed_users(self, allowed_users):
        """Sets the allowed_users of this UpdateSSHCertIssuer.

        Users allowed to fetch the certificate, e.g root,ubuntu  # noqa: E501

        :param allowed_users: The allowed_users of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and allowed_users is None:  # noqa: E501
            raise ValueError("Invalid value for `allowed_users`, must not be `None`")  # noqa: E501

        self._allowed_users = allowed_users

    @property
    def extensions(self):
        """Gets the extensions of this UpdateSSHCertIssuer.  # noqa: E501

        Signed certificates with extensions, e.g permit-port-forwarding=\\\"\\\"  # noqa: E501

        :return: The extensions of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this UpdateSSHCertIssuer.

        Signed certificates with extensions, e.g permit-port-forwarding=\\\"\\\"  # noqa: E501

        :param extensions: The extensions of this UpdateSSHCertIssuer.  # noqa: E501
        :type: dict(str, str)
        """

        self._extensions = extensions

    @property
    def json(self):
        """Gets the json of this UpdateSSHCertIssuer.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateSSHCertIssuer.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateSSHCertIssuer.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def metadata(self):
        """Gets the metadata of this UpdateSSHCertIssuer.  # noqa: E501

        A metadata about the issuer  # noqa: E501

        :return: The metadata of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this UpdateSSHCertIssuer.

        A metadata about the issuer  # noqa: E501

        :param metadata: The metadata of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def name(self):
        """Gets the name of this UpdateSSHCertIssuer.  # noqa: E501

        SSH certificate issuer name  # noqa: E501

        :return: The name of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSSHCertIssuer.

        SSH certificate issuer name  # noqa: E501

        :param name: The name of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this UpdateSSHCertIssuer.  # noqa: E501

        New item name  # noqa: E501

        :return: The new_name of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateSSHCertIssuer.

        New item name  # noqa: E501

        :param new_name: The new_name of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def principals(self):
        """Gets the principals of this UpdateSSHCertIssuer.  # noqa: E501

        Signed certificates with principal, e.g example_role1,example_role2  # noqa: E501

        :return: The principals of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._principals

    @principals.setter
    def principals(self, principals):
        """Sets the principals of this UpdateSSHCertIssuer.

        Signed certificates with principal, e.g example_role1,example_role2  # noqa: E501

        :param principals: The principals of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._principals = principals

    @property
    def rm_tag(self):
        """Gets the rm_tag of this UpdateSSHCertIssuer.  # noqa: E501

        List of the existent tags that will be removed from this item  # noqa: E501

        :return: The rm_tag of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: list[str]
        """
        return self._rm_tag

    @rm_tag.setter
    def rm_tag(self, rm_tag):
        """Sets the rm_tag of this UpdateSSHCertIssuer.

        List of the existent tags that will be removed from this item  # noqa: E501

        :param rm_tag: The rm_tag of this UpdateSSHCertIssuer.  # noqa: E501
        :type: list[str]
        """

        self._rm_tag = rm_tag

    @property
    def secure_access_bastion_api(self):
        """Gets the secure_access_bastion_api of this UpdateSSHCertIssuer.  # noqa: E501


        :return: The secure_access_bastion_api of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_api

    @secure_access_bastion_api.setter
    def secure_access_bastion_api(self, secure_access_bastion_api):
        """Sets the secure_access_bastion_api of this UpdateSSHCertIssuer.


        :param secure_access_bastion_api: The secure_access_bastion_api of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_api = secure_access_bastion_api

    @property
    def secure_access_bastion_ssh(self):
        """Gets the secure_access_bastion_ssh of this UpdateSSHCertIssuer.  # noqa: E501


        :return: The secure_access_bastion_ssh of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_ssh

    @secure_access_bastion_ssh.setter
    def secure_access_bastion_ssh(self, secure_access_bastion_ssh):
        """Sets the secure_access_bastion_ssh of this UpdateSSHCertIssuer.


        :param secure_access_bastion_ssh: The secure_access_bastion_ssh of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_ssh = secure_access_bastion_ssh

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this UpdateSSHCertIssuer.  # noqa: E501


        :return: The secure_access_enable of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this UpdateSSHCertIssuer.


        :param secure_access_enable: The secure_access_enable of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_host(self):
        """Gets the secure_access_host of this UpdateSSHCertIssuer.  # noqa: E501


        :return: The secure_access_host of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_host

    @secure_access_host.setter
    def secure_access_host(self, secure_access_host):
        """Sets the secure_access_host of this UpdateSSHCertIssuer.


        :param secure_access_host: The secure_access_host of this UpdateSSHCertIssuer.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_host = secure_access_host

    @property
    def secure_access_ssh_creds_user(self):
        """Gets the secure_access_ssh_creds_user of this UpdateSSHCertIssuer.  # noqa: E501


        :return: The secure_access_ssh_creds_user of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_ssh_creds_user

    @secure_access_ssh_creds_user.setter
    def secure_access_ssh_creds_user(self, secure_access_ssh_creds_user):
        """Sets the secure_access_ssh_creds_user of this UpdateSSHCertIssuer.


        :param secure_access_ssh_creds_user: The secure_access_ssh_creds_user of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._secure_access_ssh_creds_user = secure_access_ssh_creds_user

    @property
    def secure_access_use_internal_bastion(self):
        """Gets the secure_access_use_internal_bastion of this UpdateSSHCertIssuer.  # noqa: E501


        :return: The secure_access_use_internal_bastion of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_use_internal_bastion

    @secure_access_use_internal_bastion.setter
    def secure_access_use_internal_bastion(self, secure_access_use_internal_bastion):
        """Sets the secure_access_use_internal_bastion of this UpdateSSHCertIssuer.


        :param secure_access_use_internal_bastion: The secure_access_use_internal_bastion of this UpdateSSHCertIssuer.  # noqa: E501
        :type: bool
        """

        self._secure_access_use_internal_bastion = secure_access_use_internal_bastion

    @property
    def signer_key_name(self):
        """Gets the signer_key_name of this UpdateSSHCertIssuer.  # noqa: E501

        A key to sign the certificate with  # noqa: E501

        :return: The signer_key_name of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._signer_key_name

    @signer_key_name.setter
    def signer_key_name(self, signer_key_name):
        """Sets the signer_key_name of this UpdateSSHCertIssuer.

        A key to sign the certificate with  # noqa: E501

        :param signer_key_name: The signer_key_name of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signer_key_name is None:  # noqa: E501
            raise ValueError("Invalid value for `signer_key_name`, must not be `None`")  # noqa: E501

        self._signer_key_name = signer_key_name

    @property
    def token(self):
        """Gets the token of this UpdateSSHCertIssuer.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateSSHCertIssuer.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def ttl(self):
        """Gets the ttl of this UpdateSSHCertIssuer.  # noqa: E501

        he requested Time To Live for the certificate, in seconds  # noqa: E501

        :return: The ttl of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this UpdateSSHCertIssuer.

        he requested Time To Live for the certificate, in seconds  # noqa: E501

        :param ttl: The ttl of this UpdateSSHCertIssuer.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and ttl is None:  # noqa: E501
            raise ValueError("Invalid value for `ttl`, must not be `None`")  # noqa: E501

        self._ttl = ttl

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateSSHCertIssuer.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateSSHCertIssuer.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateSSHCertIssuer.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateSSHCertIssuer.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSSHCertIssuer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateSSHCertIssuer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class PathRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'assigners': 'list[RuleAssigner]',
        'capabilities': 'list[str]',
        'is_limit_access': 'bool',
        'number_of_access_used': 'int',
        'number_of_allowed_access': 'int',
        'path': 'str',
        'start_time': 'int',
        'ttl': 'int',
        'type': 'str'
    }

    attribute_map = {
        'assigners': 'assigners',
        'capabilities': 'capabilities',
        'is_limit_access': 'is_limit_access',
        'number_of_access_used': 'number_of_access_used',
        'number_of_allowed_access': 'number_of_allowed_access',
        'path': 'path',
        'start_time': 'start_time',
        'ttl': 'ttl',
        'type': 'type'
    }

    def __init__(self, assigners=None, capabilities=None, is_limit_access=None, number_of_access_used=None, number_of_allowed_access=None, path=None, start_time=None, ttl=None, type=None, local_vars_configuration=None):  # noqa: E501
        """PathRule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._assigners = None
        self._capabilities = None
        self._is_limit_access = None
        self._number_of_access_used = None
        self._number_of_allowed_access = None
        self._path = None
        self._start_time = None
        self._ttl = None
        self._type = None
        self.discriminator = None

        if assigners is not None:
            self.assigners = assigners
        if capabilities is not None:
            self.capabilities = capabilities
        if is_limit_access is not None:
            self.is_limit_access = is_limit_access
        if number_of_access_used is not None:
            self.number_of_access_used = number_of_access_used
        if number_of_allowed_access is not None:
            self.number_of_allowed_access = number_of_allowed_access
        if path is not None:
            self.path = path
        if start_time is not None:
            self.start_time = start_time
        if ttl is not None:
            self.ttl = ttl
        if type is not None:
            self.type = type

    @property
    def assigners(self):
        """Gets the assigners of this PathRule.  # noqa: E501


        :return: The assigners of this PathRule.  # noqa: E501
        :rtype: list[RuleAssigner]
        """
        return self._assigners

    @assigners.setter
    def assigners(self, assigners):
        """Sets the assigners of this PathRule.


        :param assigners: The assigners of this PathRule.  # noqa: E501
        :type: list[RuleAssigner]
        """

        self._assigners = assigners

    @property
    def capabilities(self):
        """Gets the capabilities of this PathRule.  # noqa: E501

        The approved/denied capabilities in the path  # noqa: E501

        :return: The capabilities of this PathRule.  # noqa: E501
        :rtype: list[str]
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """Sets the capabilities of this PathRule.

        The approved/denied capabilities in the path  # noqa: E501

        :param capabilities: The capabilities of this PathRule.  # noqa: E501
        :type: list[str]
        """

        self._capabilities = capabilities

    @property
    def is_limit_access(self):
        """Gets the is_limit_access of this PathRule.  # noqa: E501

        flag that indicate that this rule is allowed to be access RemainingAccess of times.  # noqa: E501

        :return: The is_limit_access of this PathRule.  # noqa: E501
        :rtype: bool
        """
        return self._is_limit_access

    @is_limit_access.setter
    def is_limit_access(self, is_limit_access):
        """Sets the is_limit_access of this PathRule.

        flag that indicate that this rule is allowed to be access RemainingAccess of times.  # noqa: E501

        :param is_limit_access: The is_limit_access of this PathRule.  # noqa: E501
        :type: bool
        """

        self._is_limit_access = is_limit_access

    @property
    def number_of_access_used(self):
        """Gets the number_of_access_used of this PathRule.  # noqa: E501


        :return: The number_of_access_used of this PathRule.  # noqa: E501
        :rtype: int
        """
        return self._number_of_access_used

    @number_of_access_used.setter
    def number_of_access_used(self, number_of_access_used):
        """Sets the number_of_access_used of this PathRule.


        :param number_of_access_used: The number_of_access_used of this PathRule.  # noqa: E501
        :type: int
        """

        self._number_of_access_used = number_of_access_used

    @property
    def number_of_allowed_access(self):
        """Gets the number_of_allowed_access of this PathRule.  # noqa: E501


        :return: The number_of_allowed_access of this PathRule.  # noqa: E501
        :rtype: int
        """
        return self._number_of_allowed_access

    @number_of_allowed_access.setter
    def number_of_allowed_access(self, number_of_allowed_access):
        """Sets the number_of_allowed_access of this PathRule.


        :param number_of_allowed_access: The number_of_allowed_access of this PathRule.  # noqa: E501
        :type: int
        """

        self._number_of_allowed_access = number_of_allowed_access

    @property
    def path(self):
        """Gets the path of this PathRule.  # noqa: E501

        The path the rule refers to  # noqa: E501

        :return: The path of this PathRule.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this PathRule.

        The path the rule refers to  # noqa: E501

        :param path: The path of this PathRule.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def start_time(self):
        """Gets the start_time of this PathRule.  # noqa: E501


        :return: The start_time of this PathRule.  # noqa: E501
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this PathRule.


        :param start_time: The start_time of this PathRule.  # noqa: E501
        :type: int
        """

        self._start_time = start_time

    @property
    def ttl(self):
        """Gets the ttl of this PathRule.  # noqa: E501


        :return: The ttl of this PathRule.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this PathRule.


        :param ttl: The ttl of this PathRule.  # noqa: E501
        :type: int
        """

        self._ttl = ttl

    @property
    def type(self):
        """Gets the type of this PathRule.  # noqa: E501


        :return: The type of this PathRule.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PathRule.


        :param type: The type of this PathRule.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PathRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PathRule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CacheConfigPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cache_enable': 'bool',
        'cache_ttl': 'str',
        'proactive_cache_dump_interval': 'str',
        'proactive_cache_enable': 'bool',
        'proactive_cache_minimum_fetching_time': 'str'
    }

    attribute_map = {
        'cache_enable': 'cache_enable',
        'cache_ttl': 'cache_ttl',
        'proactive_cache_dump_interval': 'proactive_cache_dump_interval',
        'proactive_cache_enable': 'proactive_cache_enable',
        'proactive_cache_minimum_fetching_time': 'proactive_cache_minimum_fetching_time'
    }

    def __init__(self, cache_enable=None, cache_ttl=None, proactive_cache_dump_interval=None, proactive_cache_enable=None, proactive_cache_minimum_fetching_time=None, local_vars_configuration=None):  # noqa: E501
        """CacheConfigPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cache_enable = None
        self._cache_ttl = None
        self._proactive_cache_dump_interval = None
        self._proactive_cache_enable = None
        self._proactive_cache_minimum_fetching_time = None
        self.discriminator = None

        if cache_enable is not None:
            self.cache_enable = cache_enable
        if cache_ttl is not None:
            self.cache_ttl = cache_ttl
        if proactive_cache_dump_interval is not None:
            self.proactive_cache_dump_interval = proactive_cache_dump_interval
        if proactive_cache_enable is not None:
            self.proactive_cache_enable = proactive_cache_enable
        if proactive_cache_minimum_fetching_time is not None:
            self.proactive_cache_minimum_fetching_time = proactive_cache_minimum_fetching_time

    @property
    def cache_enable(self):
        """Gets the cache_enable of this CacheConfigPart.  # noqa: E501


        :return: The cache_enable of this CacheConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._cache_enable

    @cache_enable.setter
    def cache_enable(self, cache_enable):
        """Sets the cache_enable of this CacheConfigPart.


        :param cache_enable: The cache_enable of this CacheConfigPart.  # noqa: E501
        :type: bool
        """

        self._cache_enable = cache_enable

    @property
    def cache_ttl(self):
        """Gets the cache_ttl of this CacheConfigPart.  # noqa: E501


        :return: The cache_ttl of this CacheConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._cache_ttl

    @cache_ttl.setter
    def cache_ttl(self, cache_ttl):
        """Sets the cache_ttl of this CacheConfigPart.


        :param cache_ttl: The cache_ttl of this CacheConfigPart.  # noqa: E501
        :type: str
        """

        self._cache_ttl = cache_ttl

    @property
    def proactive_cache_dump_interval(self):
        """Gets the proactive_cache_dump_interval of this CacheConfigPart.  # noqa: E501


        :return: The proactive_cache_dump_interval of this CacheConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._proactive_cache_dump_interval

    @proactive_cache_dump_interval.setter
    def proactive_cache_dump_interval(self, proactive_cache_dump_interval):
        """Sets the proactive_cache_dump_interval of this CacheConfigPart.


        :param proactive_cache_dump_interval: The proactive_cache_dump_interval of this CacheConfigPart.  # noqa: E501
        :type: str
        """

        self._proactive_cache_dump_interval = proactive_cache_dump_interval

    @property
    def proactive_cache_enable(self):
        """Gets the proactive_cache_enable of this CacheConfigPart.  # noqa: E501


        :return: The proactive_cache_enable of this CacheConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._proactive_cache_enable

    @proactive_cache_enable.setter
    def proactive_cache_enable(self, proactive_cache_enable):
        """Sets the proactive_cache_enable of this CacheConfigPart.


        :param proactive_cache_enable: The proactive_cache_enable of this CacheConfigPart.  # noqa: E501
        :type: bool
        """

        self._proactive_cache_enable = proactive_cache_enable

    @property
    def proactive_cache_minimum_fetching_time(self):
        """Gets the proactive_cache_minimum_fetching_time of this CacheConfigPart.  # noqa: E501


        :return: The proactive_cache_minimum_fetching_time of this CacheConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._proactive_cache_minimum_fetching_time

    @proactive_cache_minimum_fetching_time.setter
    def proactive_cache_minimum_fetching_time(self, proactive_cache_minimum_fetching_time):
        """Sets the proactive_cache_minimum_fetching_time of this CacheConfigPart.


        :param proactive_cache_minimum_fetching_time: The proactive_cache_minimum_fetching_time of this CacheConfigPart.  # noqa: E501
        :type: str
        """

        self._proactive_cache_minimum_fetching_time = proactive_cache_minimum_fetching_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CacheConfigPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CacheConfigPart):
            return True

        return self.to_dict() != other.to_dict()
